package com.hungraim.ltc.dao;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.pojo.entity.assessment.ChAprTask;
import com.hungraim.ltc.pojo.vo.assessment.*;
import org.apache.ibatis.annotations.Mapper;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 失能评定Mapper
 *
 * @author czz
 */
@Mapper
@Repository
public interface TaskMapper extends BaseMapper<ChAprTask> {

    /**
     * 评定任务分配列表
     *
     * @param organIds      适用机构代码
     * @param provincial    所在省
     * @param city          所在市
     * @param area          所在区域
     * @param street        所在街道
     * @param realName      失能人员姓名
     * @param certiCode     失能人员身份证号码
     * @param taskName      评定人员姓名
     * @param taskTel       评定人员手机号码
     * @param daysRemaining 评定剩余天数
     * @param status        任务状态
     * @param isReturn      是否退回
     */
    Page<TaskDistributionVO> taskDistributionList(Page<TaskDistributionVO> page, List<String> organIds, String provincial, String city,
                                                  String street, String realName, String certiCode, String taskName, String taskTel,
                                                  String daysRemaining, String status, String isReturn, String area);

    /**
     * 评定报告录入列表
     */
    List<TaskReportVO> taskReportList(String name, String certiCode, String tel);

    List<TaskGroupVO> taskGroupList(String name, String certiCode, String tel);

    List<AprEmpVO> aprEmpList(String organName, String name, String tel, String groupLeader);

    List<PersonInfoVO> personInfoList(String reportId);

    List<TaskGroupInfoVO> taskGroupInfoList(String groupNumber);

    TaskGroupInfoListInfoVO taskGroupInfoListInfo(String pushId);

    List<AllotTaskHisVO> allotTaskHisList();
}
