package com.hungraim.ltc.gateway.config;

import com.hungraim.ltc.util.Result;
import com.hungraim.ltc.util.ResultCode;
import lombok.extern.slf4j.Slf4j;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.oauth2.common.exceptions.InvalidGrantException;
import org.springframework.security.oauth2.common.exceptions.OAuth2Exception;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseBody;

/**
 * 异常全局处理
 * @author hubin
 */
@ControllerAdvice
@Slf4j
public class GlobalExceptionHandler {


  /**
   * 身份验证异常
   * @param e 异常实例
   * @return 返回信息
   */
  @ExceptionHandler(AuthenticationException.class)
  @ResponseBody
  public Result<Exception> authenticationExceptionHandler(AuthenticationException e){
    log.warn("authenticationExceptionHandler:{}",e.getMessage());
    return Result.failed();
  }

  /**
   * OAUTH2身份验证异常
   * @param e 异常实例
   * @return 返回信息
   */
  @ExceptionHandler(OAuth2Exception.class)
  @ResponseBody
  public Result<Exception> oAuth2ExceptionHandle(OAuth2Exception e){
    log.warn("oAuth2ExceptionHandler:{}",e.getMessage());
    if(e instanceof InvalidGrantException){
      return Result.failed(ResultCode.USERNAME_OR_PASSWORD_ERROR);
    }
    return Result.failed(e.getMessage());
  }

}
