package com.hungraim.ltc.service;

import com.hungraim.ltc.api.SystemAdminFeignService;
import com.hungraim.ltc.pojo.entity.system.SystemUser;
import com.hungraim.ltc.pojo.vo.system.UserLoginInfoVO;
import com.hungraim.ltc.util.Result;
import com.hungraim.ltc.util.ResultCode;
import lombok.AllArgsConstructor;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author hubin
 */
@Service
@AllArgsConstructor
public class UserDetailsServiceImpl implements UserDetailsService {

    private final SystemAdminFeignService systemAdminFeignService;


    @Override
    public UserDetails loadUserByUsername(String account) throws UsernameNotFoundException {
        //获取用户基本信息
        Result<SystemUser> userRes = systemAdminFeignService.loadUserInfoByAccount(account);
        //用户不存在
        if (ResultCode.USER_NOT_EXIST.getCode().equals(userRes.getCode())) {
            throw new UsernameNotFoundException(ResultCode.USER_NOT_EXIST.getMsg());
        }
        SystemUser systemUser = userRes.getData();
        //根据用户id获取用户权限
        Result<List<Long>> roles = systemAdminFeignService.loadUserRolesByUserId(systemUser.getUserId());
        UserLoginInfoVO userLoginInfoVO = new UserLoginInfoVO(systemUser);
        userLoginInfoVO.setAuthorities(roles.getData());

        return userLoginInfoVO;
    }
}
