package com.hungraim.ltc.pojo.vo.system;

import cn.hutool.core.collection.CollectionUtil;
import com.hungraim.ltc.pojo.entity.system.SystemUser;
import lombok.Data;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.authority.SimpleGrantedAuthority;
import org.springframework.security.core.userdetails.UserDetails;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

/**
 * @author hubin
 */
@Data
public class UserLoginInfoVO implements UserDetails {
    private Collection<SimpleGrantedAuthority> authorities;
    private final String username;
    private final String password;
    private final String name;
    private final Long userId;
    private String avatar;
    private final Boolean enable;

    public UserLoginInfoVO(SystemUser user) {
        this.username = user.getAccount();
        this.password = user.getPassword();
        this.name = user.getRealName();
        this.userId = user.getUserId();
        this.enable = user.getUserStatus() == 1;
    }

    public void setAuthorities(List<Long> roles) {
        if (CollectionUtil.isNotEmpty(roles)) {
            authorities = new ArrayList<>();
            roles.forEach(roleId -> authorities.add(new SimpleGrantedAuthority(String.valueOf(roleId))));
        }
    }

    @Override
    public Collection<? extends GrantedAuthority> getAuthorities() {
        return this.authorities;
    }

    @Override
    public String getPassword() {
        return this.password;
    }

    @Override
    public String getUsername() {
        return this.username;
    }

    @Override
    public boolean isAccountNonExpired() {
        return this.enable;
    }

    @Override
    public boolean isAccountNonLocked() {
        return true;
    }

    @Override
    public boolean isCredentialsNonExpired() {
        return true;
    }

    @Override
    public boolean isEnabled() {
        return this.enable;
    }


}
