package com.hungraim.ltc.gateway.service.impl;

import com.alibaba.nacos.client.naming.utils.CollectionUtils;
import com.hungraim.ltc.gateway.service.INacosDynamicRouteService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.gateway.event.RefreshRoutesEvent;
import org.springframework.cloud.gateway.route.RouteDefinition;
import org.springframework.cloud.gateway.route.RouteDefinitionLocator;
import org.springframework.cloud.gateway.route.RouteDefinitionWriter;
import org.springframework.context.ApplicationEventPublisher;
import org.springframework.stereotype.Service;
import reactor.core.publisher.Mono;

import java.util.List;

/**
 * @author hubin
 */
@Service
@Slf4j
public class NacosDynamicRouteServiceImpl implements INacosDynamicRouteService {

  private final RouteDefinitionWriter routeDefinitionWriter;

  private final ApplicationEventPublisher publisher;

  private final RouteDefinitionLocator routeDefinitionLocator;

  @Autowired
  public NacosDynamicRouteServiceImpl(RouteDefinitionWriter routeDefinitionWriter, ApplicationEventPublisher publisher, RouteDefinitionLocator routeDefinitionLocator) {
    this.routeDefinitionWriter = routeDefinitionWriter;
    this.publisher = publisher;
    this.routeDefinitionLocator = routeDefinitionLocator;
  }

  @Override
  public void delete(String id) {
    log.info("gateway delete route id {}", id);
    this.routeDefinitionWriter.delete(Mono.just(id)).subscribe();
    this.publisher.publishEvent(new RefreshRoutesEvent(this));
  }

  @Override
  public void updateList(List<RouteDefinition> definitions) {
    log.info("gateway update route {}", definitions);
    // 删除缓存routerDefinition
    List<RouteDefinition> routeDefinitionsExits = routeDefinitionLocator.getRouteDefinitions().buffer().blockFirst();
    if (!CollectionUtils.isEmpty(routeDefinitionsExits)) {
      routeDefinitionsExits.forEach(routeDefinition -> {
        log.info("delete routeDefinition:{}", routeDefinition);
        delete(routeDefinition.getId());
      });
    }
    definitions.forEach(this::updateById);
  }

  @Override
  public void updateById(RouteDefinition definition) {
    log.info("gateway update route {}", definition);
    this.routeDefinitionWriter.delete(Mono.just(definition.getId()));
    routeDefinitionWriter.save(Mono.just(definition)).subscribe();
    this.publisher.publishEvent(new RefreshRoutesEvent(this));
  }

  @Override
  public void add(RouteDefinition definition) {
    log.info("gateway add route {}", definition);
    routeDefinitionWriter.save(Mono.just(definition)).subscribe();
    this.publisher.publishEvent(new RefreshRoutesEvent(this));
  }
}
