package com.hungraim.ltc.governance.controller;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.pojo.entity.assessment.ChAprTask;
import com.hungraim.ltc.pojo.entity.disable.ChDisableInfo;
import com.hungraim.ltc.pojo.entity.serviceManage.ChSrvSend;
import com.hungraim.ltc.governance.service.*;
import com.hungraim.ltc.pojo.entity.disable.ChSrvOrgan;
import com.hungraim.ltc.pojo.entity.governance.ChSrvBuildBed;
import com.hungraim.ltc.pojo.vo.disable.ChrSrvVo;
import com.hungraim.ltc.pojo.vo.governance.BuildBedSearchReq;
import com.hungraim.ltc.pojo.vo.governance.DisableInfoTaskVO;
import com.hungraim.ltc.pojo.vo.governance.DisableInfoVo;
import com.hungraim.ltc.pojo.vo.governance.SrvSendVO;
import com.hungraim.ltc.util.Result;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author jiaguokai
 */
@RestController
@RequestMapping("/api.governance/buildBed")
@Slf4j
public class BuildBedController {
    @Resource
    private IBuildBedService buildBedService;
    @Resource
    private SrvSendService sendService;
    @Resource
    private CrvService crvService;
    @Autowired
    private DisableInfoServie disableInfoServie;

    @Resource
    private DisableEvaluateService disableEvaluateService;


    @PostMapping("/searchOrgBed")
    public Result searchOrgBed(@RequestBody BuildBedSearchReq req) {
        return buildBedService.searchOrgBed(req);
    }

    @PostMapping("/addBuild")
    public Result<Boolean> buildBed(ChSrvBuildBed buildBed) {
        boolean b = buildBedService.save(buildBed);
        return Result.success(b);
    }

    /**
     * 功能描述: 服务分配信息检索条件查询
     */
    @PostMapping("/pageFuwuCondition")
    public Result pageFuwuCondition(ChDisableInfo disableInfo, ChSrvOrgan chSrvOrgan, ChSrvSend chSrvSend) {

        // 创建一个page对象
        IPage<SrvSendVO> page = sendService.selectPage(disableInfo, chSrvOrgan, chSrvSend);
        // 总记录数
        long total = page.getTotal();
        List<SrvSendVO> records = page.getRecords();
        Map map = new HashMap<>();
        map.put("total", total);
        map.put("records", records);
        return Result.success(map);
    }

    /**
     * 根据id查询失能人员的评定信息
     */
    @PostMapping("/queryEvaluateById")
    public Result queryEvaluateById(SrvSendVO srvSendVO) {
        Integer disableInfoId = srvSendVO.getDisableInfoId();
        Integer srvOrganId = srvSendVO.getSrvOrganId();
        if (StrUtil.isBlankIfStr(disableInfoId)) {
            return Result.failed("失能人员ID 为空！");
        }
        if (StrUtil.isBlankIfStr(srvOrganId)) {
            return Result.failed("机构id不能为空");
        }
        DisableInfoTaskVO disableInfoTaskVO = sendService.selectTaskById(disableInfoId, srvOrganId);
        List<DisableInfoTaskVO> disableInfoTaskVO1 = sendService.selectBydisableInfoId(disableInfoId);
        Map map = new HashMap<>();
        map.put("disableInfoTaskVO", disableInfoTaskVO);
        map.put("chAprTasks", disableInfoTaskVO1);
        return Result.success(map);
    }


    /**
     * 护理机构及服务方式檢索
     */
    @GetMapping("/PageCrv")
    public Result PageCrv(HttpServletRequest request, ChSrvOrgan chSrvOrgan) {
        // 调用方法实现分页查询
        IPage<ChSrvOrgan> page = crvService.seletSrvOrganPage(chSrvOrgan);
        // 总记录数
        long total = page.getTotal();
        List<ChSrvOrgan> records = page.getRecords();
        Map map = new HashMap<>();
        map.put("total", total);
        map.put("recors", records);
        return Result.success(map);
    }

    /**
     *已分配护理机构信息查询
     */
    @PostMapping("/querySrvYet")
    public Result querySrvYet(DisableInfoVo disableInfoVo){
        if (StrUtil.isBlankIfStr(disableInfoVo.getDisableInfoId())){
            return Result.failed("失能人员id不能为空");
        }
        Page<DisableInfoVo> disableInfoVos = disableInfoServie.querySrvYet(disableInfoVo.getDisableInfoId(),disableInfoVo.getCurrent(),disableInfoVo.getLimit());
        long total = disableInfoVos.getTotal();
        List<DisableInfoVo> records = disableInfoVos.getRecords();
        Map map = new HashMap<>();
        map.put("total", total);
        map.put("recors", records);
        return Result.success(map);
    }

    /**
     * 提交分配机构
     */
    @PostMapping("/submit")
    public Result submit(ChrSrvVo  chrSrvVo) {
        List<ChSrvSend> chSrvSends = chrSrvVo.getChSrvSends();
        if (chSrvSends != null && chSrvSends.size() > 0) {
            Long disabInfoId = null;
            for (ChSrvSend chSrvSend : chSrvSends) {
                disabInfoId = chSrvSend.getDisabInfoId();
                // 判斷參數是否存在
                if (chSrvSend.getDisabInfoId()==null || chSrvSend.getSrvOrganId()==null || chSrvSend.getSrvModeId()==null) {
                    return Result.failed("参数不全！");
                }
                chSrvSend.setAllotTime(new Date());
                chSrvSend.setStatus(Short.valueOf("1"));
                if(chrSrvVo.getSrvSendId() == null){
                    Long id = sendService.selectMaxId();
                    if(id == null){
                        id = 0l;
                    }
                    chSrvSend.setSrvSendId(++id);
                }
                sendService.saveOrUpdate(chSrvSend);
            }
        } else {
            return Result.failed("提交失败，参数为空");
        }
        return Result.success();

    }


}

