package com.hungraim.ltc.governance.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.pojo.entity.serviceManage.ChSrvProgram;
import com.hungraim.ltc.pojo.vo.governance.ProgramDetailVo;
import com.hungraim.ltc.pojo.vo.governance.ProgramListVo;
import com.hungraim.ltc.pojo.vo.governance.SvrSendListVo;

import java.util.List;

public interface SrvProgramService {

    /**
     * 个人照护方案查询列表
     *
     * @param srvOrganId    服务机构id
     * @param realName      失能人员姓名
     * @param realTel       失能人员手机号
     * @param programStatus 服务方案状态
     * @return 返回列表
     */
    Page<SvrSendListVo> getProgramList(Page<SvrSendListVo> page, Long srvOrganId, String realName, String realTel, String programStatus);

    /**
     * 个人照护方案列表查询
     *
     * @param page          分页参数
     * @param disabInfoId   失能人员id
     * @param srvOrganId    服务机构id
     * @param programStatus 服务方案状态  0：未生效、1：已生效、2：已终止
     * @return 返回个人照护方案列表
     */
    Page<ProgramListVo> getProgramSetList(Page<ProgramListVo> page, Long disabInfoId, Long srvOrganId, String programStatus);

    /**
     * 个人照护方案记录条数，查询对应方案状态的记录条数
     *
     * @param disabInfoId   失能人员id
     * @param srvOrganId    服务机构id
     * @param programStatus 服务方案状态  0：未生效、1：已生效、2：已终止
     * @return 返回条数
     */
    List<ChSrvProgram> getProgramSetCountByProgStatus(Long disabInfoId, Long srvOrganId, String programStatus);

    /**
     * 查看服务方案详情
     *
     * @param programId 方案id
     * @return 返回服务方案详情
     */
    ProgramDetailVo getProgramDetail(Long programId);

    /**
     * 添加服务方案时需要展示的相关信息
     *
     * @param disabInfoId 失能人员id
     * @param srvOrganId  服务机构id
     * @return 返回添加服务方案需要展示的信息
     */
    ProgramDetailVo getProgramDetailWithAdd(Long disabInfoId, Long srvOrganId);

    /**
     * 添加或者修改服务方案
     * @param programDetailVo 包装对象
     */
    void addProgramAndProgramSetList(ProgramDetailVo programDetailVo);

    /**
     * 终止服务方案
     *
     * @param programId 服务方案id
     * @param endReason 终止原因
     */
    void endProgram(Long programId, String endReason);
}
