package com.hungraim.ltc.system.controller;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.pojo.entity.system.SystemResource;
import com.hungraim.ltc.pojo.entity.system.SystemRoleResource;
import com.hungraim.ltc.pojo.vo.system.MainMenuVO;
import com.hungraim.ltc.pojo.vo.system.ReqResource;
import com.hungraim.ltc.system.service.ISystemResourceService;
import com.hungraim.ltc.system.service.ISystemRoleResourceService;
import com.hungraim.ltc.util.Result;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author hubin
 */
@RestController
@RequestMapping("/api.system/resource")
@Slf4j
public class ResourcesController {

    @Autowired
    private ISystemResourceService resourceService;

    @Autowired
    private ISystemRoleResourceService roleResourceService;


    /**
     * 获取主菜单信息
     * @return
     */
    @GetMapping("/getManinMenu")
    public Result getMainMenu() {

        //查出所有菜单 并且转换成菜单vo
        List<MainMenuVO> resourceList = resourceService.list(new LambdaQueryWrapper<SystemResource>().eq(SystemResource::getResourceType, "2"))
            .stream().map(item -> {
                MainMenuVO mainMenuVO = new MainMenuVO();
                mainMenuVO.setIcon(item.getResourceIcon());
                mainMenuVO.setName(item.getResourceName());
                mainMenuVO.setId(item.getResourceId());
                mainMenuVO.setParentId(item.getParentId());
                mainMenuVO.setPath(item.getResourceUrl());
                return mainMenuVO;
            }).collect(Collectors.toList());
        //转成tree形式菜单数据
        List<MainMenuVO> result = resourceList.stream().filter(item -> 0 == item.getParentId()).peek(item -> item.setChildren(getChildren(item, resourceList))
        ).collect(Collectors.toList());
        return Result.success(result);
    }

    /**
     * 递归获取子菜单
     *
     * @param root
     * @param all
     * @return
     */
    public static List<MainMenuVO> getChildren(MainMenuVO root, List<MainMenuVO> all) {
        return all.stream().filter(item -> item.getParentId().equals(root.getId()))
            .peek((item) -> item.setChildren(getChildren(item, all))).collect(Collectors.toList());
    }


    @PostMapping("/addResource")
    public Result addResource(ReqResource reqResource){

        if (StrUtil.isBlankIfStr(reqResource.getName())) {
            return Result.failed("资源类型不能为空！");
        }
        if (StrUtil.isBlankIfStr(reqResource.getType())) {
            return Result.failed("资源名称不能为空！");
        }

        SystemResource systemResource = new SystemResource();
        systemResource.setResourceName(reqResource.getName());
        systemResource.setResourceUrl(reqResource.getUrl());
        systemResource.setResourceType(reqResource.getType());
        systemResource.setResourceId(reqResource.getId());
        systemResource.setResourceIcon(reqResource.getIcon());
        systemResource.setParentId(reqResource.getParentId());
        systemResource.setCreatedTime(new Date());
        resourceService.save(systemResource);

        SystemRoleResource systemRoleResource = new SystemRoleResource();
        systemRoleResource.setResourceId(systemResource.getResourceId());
        systemRoleResource.setRoleId(0L);
        roleResourceService.save(systemRoleResource);

        return  Result.success("插入成功");
    }

    @PostMapping("/queryResources")
    public Result queryResources(ReqResource reqResource,
                                 @RequestParam(defaultValue = "1") int pageNum, @RequestParam(defaultValue = "20") int pageSize){
        QueryWrapper<SystemResource> systemResourceQueryWrapper = new QueryWrapper<>();
        if (!StrUtil.isBlankIfStr(reqResource.getName())) {
            systemResourceQueryWrapper.or(wrapper -> wrapper.lambda().like(SystemResource::getResourceName, reqResource.getName()));
        }
        if (!StrUtil.isBlankIfStr(reqResource.getUrl())) {
            systemResourceQueryWrapper.or(wrapper -> wrapper.lambda().like(SystemResource::getResourceUrl, reqResource.getUrl()));
        }
        systemResourceQueryWrapper.orderByAsc("resource_id");

        return  Result.success(resourceService.page(new Page<>(pageNum, pageSize), systemResourceQueryWrapper));
    }



}
