package com.hungraim.ltc.system.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.hungraim.ltc.constant.AuthConstants;
import com.hungraim.ltc.pojo.entity.system.SystemResource;
import com.hungraim.ltc.system.dao.SystemResourceMapper;
import com.hungraim.ltc.system.service.ISystemResourceService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;

/**
 * @author hubin
 */
@Service
@Slf4j
public class SystemResourceServiceImpl extends ServiceImpl<SystemResourceMapper, SystemResource> implements ISystemResourceService {


  private final RedisTemplate redisTemplate;

  @Autowired
  public SystemResourceServiceImpl(RedisTemplate redisTemplate) {
    this.redisTemplate = redisTemplate;
  }


  /**
   * 将mysql中的资源角色关系缓存到redis中
   */
  @Override
  @SuppressWarnings("unchecked")
  public void refreshPermissionRolesCache(){
    log.info("refreshPermissionRolesCache run...");
    redisTemplate.delete(AuthConstants.PERMISSION_ROLES_KEY);
    List<SystemResource> permissions = this.listResourceRoles();
    Map<String, List<String>> permissionRoles = new TreeMap<>();
    Optional.ofNullable(permissions).orElse(new ArrayList<>()).forEach(permission -> {
      // 转换 roleId -> ROLE_{roleId}
      List<String> roles = Optional.ofNullable(permission.getRoleIds())
        .orElse(new ArrayList<>())
        .stream()
        .map(roleId -> AuthConstants.AUTHORITY_PREFIX + roleId)
        .collect(Collectors.toList());
      if (CollectionUtil.isNotEmpty(roles)) {
        permissionRoles.put(permission.getMethod() +"_"+ permission.getResourceUrl(), roles);
      }
    });
    redisTemplate.opsForHash().putAll(AuthConstants.PERMISSION_ROLES_KEY, permissionRoles);
  }

  @Override
  public List<SystemResource> listResourceRoles() {
    return this.baseMapper.listResourceRoles();
  }


}
